# 2ch-downloader

Download all images of 2ch.hk thread

## Installation

``` sh
pip install 2ch-downloader
```

## Usage

```
usage: 2ch-downloader [-h] [-d DIRECTORY] [--max-directory-name-length LENGTH] URL

positional arguments:
  URL                   Thread url

options:
  -h, --help            show this help message and exit
  -d DIRECTORY, --directory DIRECTORY
                        Download directory
  --max-directory-name-length LENGTH
                        Max thread directory name length, 128 by default
```

